<template>
  <div class="riskBox">
    <el-form ref="formRef" :model="state.formData" :rules="state.rules" class="register-form" label-position="top">
      <el-form-item prop="conclusion" label="评价结论">
        <el-input
            v-model="state.formData.conclusion"
            :autosize="{ minRows: 6 }"
            maxlength="500"
            show-word-limit
            type="textarea">
        </el-input>
      </el-form-item>
      <el-row :gutter="30">
        <el-col :span="9">
          <el-form-item prop="isReviseManual" label="是否有评价报告修改说明">
            <el-radio-group v-model="state.formData.isReviseManual" >
              <el-radio :label="1">是</el-radio>
              <el-radio :label="0">否</el-radio>
            </el-radio-group>
          </el-form-item>
        </el-col>
      </el-row>
      <el-row :gutter="30">
        <el-col :span="18">
          <el-form-item>
            <el-upload accept="image/*,.pdf,.doc,.docx,.xlsx,.xls"
                       :action="state.uploadUrl"
                       :disabled="state.disabled"
                       :headers="state.header"
                       method="post"
                       :on-success="handleAvatarSuccess"
                       :on-exceed="showTip"
                       v-model:file-list="state.fileList"
                       :on-remove="handleRemove"
                       :data="state.uploadData"
                       :on-preview="handlePreview"
                       :limit='1'
            >
              <el-button type="primary">附件上传</el-button>
              <template #tip>
                <div class="el-upload__tip">上传文件尺寸小于5M,最多可上传1份</div>
              </template>
            </el-upload>
          </el-form-item>
        </el-col>
      </el-row>
    </el-form>
  </div>
</template>
<script setup>

import {defineEmits, defineProps, onMounted, reactive, ref} from "vue";
import {ElMessage, ElMessageBox} from "element-plus";
import {Search} from '@element-plus/icons-vue'
import {addRate, addRisk, editRate, editRisk, getRateDetail, getRiskDetail} from "@/api/projectManage/riskAnalysis"
import {delPic} from "@/api/login"
import { getToken } from "@/utils/auth";
import Cookies from "js-cookie"
import {delAccessoryFile, getAccessoryFile} from "@/api/projectManage/project";
import axios from "axios";
import {delFile, getFiles} from "@/api/projectManage/siteCheckRcd";
const emit = defineEmits(["getNextStatus"]);
const prop = defineProps(['projectId'])
const state = reactive({
  formData: {
    isReviseManual: 0,
  },
  rules: {
    conclusion: [{required: true, message: '请输入评价结论', trigger: 'blur'}],
  },
  imgLimit: 3,
  uploadUrl: import.meta.env.VITE_APP_BASE_API + '/manage/accessory-file/uploadFile',
  header: {
    Authorization: getToken()
  },
  fileList: [],
  uploadData: {
    moduleType: 7
  },
  disabled: false
})
const props = {
  expandTrigger: 'hover',
  value: 'name',
  label: 'name'
}
const isAmin = ref(false)
const formRef = ref()
onMounted(() => {
  const userInfo = JSON.parse(Cookies.get('userInfo'))
  if(userInfo.identity === 0){
    isAmin.value = true;
  }
  if(prop.projectId){
    const val = prop.projectId;
    state.uploadData.projectId = val;
    getProcessFiles(val);
  }
})

const riskOpen = async (type,val) => {
  state.uploadData.projectId = val;
  if(type === 'detail' || type === 'edit' ){
    if(type === 'detail'){
      state.disabled = true
    }
    const res = await getRateDetail({projectId: val});
    if(res.code == 200){
      if(res.data){
        state.formData = res.data;
        state.formData.isReviseManual = res.data.isReviseManual ? 1 : 0
        state.fileList = res.data.accessoryFiles.map(item => {
          return {
            ...item,
            name: item.originName,
          }
        })
      }
    }else {
      ElMessage.warning(res.message)
    }
  }
  if(type === 'add' || type === 'clickEdit') {
    const valid = await formRef.value.validate();
    if(valid){
      if (isAmin.value) {
        ElMessage.warning("当前用户暂无权限");
        return;
      }
      if(type === 'add'){
        const {id,attachments, ...data} = JSON.parse(JSON.stringify(state.formData))
        data.projectId = val;
        const res = await addRate(data);
        if (res.code == 200) {
          ElMessage.success('保存成功')
          formRef.value.clearValidate();
          emit('getNextStatus', val);

        } else {
          ElMessage.warning(res.message)
        }
      }else if(type === 'clickEdit'){
        const { attachments, ...data} = JSON.parse(JSON.stringify(state.formData))
        const res = await editRate(data);
        if (res.code == 200) {
          ElMessage.success('变更成功')
          formRef.value.clearValidate();
          // emit('getNextStatus', data.project.id);
        } else {
          ElMessage.warning(res.message)
        }
      }
    }
  }
}

// 上传
const showTip =()=>{
  ElMessage({
    type: 'warning',
    message: '超出文件上传数量'
  });
}

const picSize = async (rawFile) => {
  if(rawFile.size / 1024 / 1024 > 2){
    ElMessage({
      type: 'warning',
      message: '文件大小不能超过2M'
    });
    return false
  }
};

const handleAvatarSuccess = (res) => {
  if(res.code === 200){
    getProcessFiles()
    console.log("if",state.fileList)
    ElMessage({
      type: 'success',
      message: '文件上传成功'
    })
  }else {
    ElMessage({
      type: 'warning',
      message: '文件上传失败'
    })
  }
}
const handlePreview = (file) => {
  let path = "";
  if(file.path){
    path = file.path
  }else {
    path = file.response.data.path

  }
  const url = import.meta.env.VITE_APP_BASE_API + '/' + path
  axios.get( url,{
        headers:
            {
              'Content-Type': 'application/json',
              'Authorization':getToken(),
            },
        responseType: 'blob'
      }
  ).then(res=>{
    if (res) {
      const link = document.createElement('a')
      let blob = new Blob([res.data],{type: res.data.type})
      link.style.display = "none";
      link.href = URL.createObjectURL(blob); // 创建URL
      link.setAttribute("download", file.name);
      document.body.appendChild(link);
      link.click();
      document.body.removeChild(link);
    } else {
      this.$message.error('获取文件失败')
    }
  })
}
const getProcessFiles = async (id)=>{
  const res = await getFiles({projectId: id ? id : prop.projectId ,moduleType: 7})
  if(res.code == 200){
    if(res.data && res.data.length>0){
      state.fileList = res.data.map(i=>{
        return {
          name: i.originName,
          url: import.meta.env.VITE_APP_BASE_API + '/' + i.path,
          id: i.id,
          projectId: i.projectId,
          moduleType: i.moduleType
        }
      })
    }else{
      state.fileList = []
    }
  }else {
    ElMessage.warning(res.message)
  }
}

const handleRemove = async (file, uploadFiles) => {
  ElMessageBox.confirm(
      '确定删除该附件？',
      '提示',
      {
        confirmButtonText: '确定',
        cancelButtonText: '取消',
        type: 'warning',
      })
      .then( async() => {
        let accessoryFileId = "";
        if(file.id){
          accessoryFileId = file.id
        }else {
          accessoryFileId = file.response.data.id
        }
        const res = await delAccessoryFile(accessoryFileId)
        if(res.code == 200){
          ElMessage({
            type: 'success',
            message: '文件已删除'
          })
          await getProcessFiles()
        }else{
          ElMessage({
            type: 'warning',
            message: res.message
          })
        }
      })
      .catch(()=>{
        getProcessFiles()
      })
}

defineExpose({
  riskOpen
});


</script>
<style scoped lang="scss">
.riskBox{
  :deep(.el-form .el-form-item__label) {
    font-size: 15px;
  }
}

</style>
